model<- nimbleCode({
  
  ## Definition of priors
  alpha_p ~ dnorm(0,0.01)
  alpha1_p ~ dnorm(0,0.01)
  alpha2_p ~ dnorm(0,0.01)
  alpha3_p ~ dnorm(0,0.01)

  tau_p <- pow(sigma_p,-2)
  sigma_p ~ dunif(0,10)
  
  alpha_q ~ dnorm(0,0.01)
  alpha1_q ~ dnorm(0,0.01)
  alpha2_q ~ dnorm(0,0.01)
  alpha3_q ~ dnorm(0,0.01)

  tau_q <- pow(sigma_q,-2)
  sigma_q ~ dunif(0,10)
 
  ## Concentration factor for the dirichlet distribution
  eta_alphaNm ~ dunif(0.01,300)

  
  ## Data format 
  ## 1: average discharge
  ## 2: average temperature 
  ## 3: 'average' day
  
  # probability of smolts leaving on day i (function of temperature and discharge)
  for(i in 1:I_nDays){
    logit(p[i]) <- L_p[i]
    L_p[i] ~ dnorm( L_mu_p[i] , tau_p)
    L_mu_p[i] <- alpha_p + alpha1_p * Data[i,1] + alpha2_p * Data[i,2] + alpha3_p * Data[i,3] #+ 
  }
  
  ## Expected proportion of smolt leaving on day i  (centering)
  P_sm[1] <- p[1]
  for(i in 2:I_nDays_min1){
    P_sm[i] <- (1-sum(P_sm[1:(i-1)])) * p[i]
  }
  P_sm[I_nDays] <- 1-sum(P_sm[1:90])
  
  ## Because it is likely that the smolts are not leaving exactly based on these proportions
  ## We account for overdispersion by approximating a dirichlet distribution with overdispersion 
  ## eta_alphaNm (approximated with gamma distributions ) 
  ## this might be year specific... 
  
  alpha_P_sm[1:I_nDays] <- (P_sm[1:I_nDays] * eta_alphaNm) + 0.1 #add for numerical stability
  
  for(i in 1:I_nDays){
    dir_x[i] ~ dgamma(alpha_P_sm[i],1)#T(0.001,)
  }
  pNm[1:I_nDays] <- dir_x[1:I_nDays]/sum(dir_x[1:I_nDays])
  
  ## NmTot[t]: Total number of smolts leaving in year t
  ## Nm[t,i]: number of smolts leaving on day i in year t
  NmTot <- exp(L_NmTot)
  L_NmTot ~ dunif(7,13.13)
  
  for(z in 1:I_nDays_min1){
    Nm[z] <-round(pNm[z] * NmTot)  
  }
  Nm[I_nDays] <-round(NmTot - sum(Nm[1:I_nDays_min1]) )

  ## Observation process
  for(i in 1:I_n_days_w){ ## Setting up all the daily parameters + first captures
    
    ##  loop indexes need to start at 1 in JAGS if any variables are only assigned within the loop
    ## 
    
    # Catchability of smolts on day i
    logit(q[i]) <- L_q[i]
    
    L_q[i] ~ dnorm(mu_q[i],tau_q)
    mu_q[i] <- alpha_q + alpha1_q * Data[i,1] + alpha2_q * Data[ i,2] + alpha3_q * Data[ i,3]

    
    # Captures - be careful to put the right day for the number of smolts 
    data_RT[i] ~ dbin(q[i] , Nm[I_RT_y[i]])

    
  }  

  
} ## End Model
)